starcluster.templates.user_msgs

Package starcluster :: Package templates :: Module user_msgs |
[hide private]
[frames] | no frames]

# Module user_msgs

source code

Variables | [hide private]
| active_ebs_cluster = ``'``EBS Cluster \'%(cluster_name)s\' already``...``
| stopped_ebs_cluster = ``'``Stopped EBS Cluster \'%(cluster_name)s\``...``
| cluster_exists = ``'``Cluster with tag name %(cluster_name)s alrea``...``
| cluster_started_msg = ``'``\n\nThe cluster has been started and co``...``
| spotmsg = ``'``SPOT INSTANCES ARE NOT GUARANTEED TO COME UP\n\nSpo``...``
| version_mismatch = ``'``The cluster \'%(cluster)s\' was created wi``...``
| __package__ = `None` hash(x)

Variables Details | [hide private]

  ### active_ebs_cluster Value:
      '''EBS Cluster \'%(cluster_name)s\' already exists.

      Either choose a different tag name, or stop the EBS cluster using:

        $ starcluster stop %(cluster_name)s

      This command will put all nodes into a \'stopped\' state and preserve
      their local disks. The cluster can later be resumed by passing the -x
      ...

  ### stopped_ebs_cluster Value:
      '''Stopped EBS Cluster \'%(cluster_name)s\' already exists.

      Either choose a different tag name, or start the stopped EBS cluster u
      sing:

        $ starcluster start %(cluster_name)s -x

      Another option is to terminate the existing EBS Cluster using:
      ...

  ### cluster_exists Value:
      '''Cluster with tag name %(cluster_name)s already exists.

      If you want to reconfigure the existing instances use the \'restart\'
      command:

        $ starcluster restart %(cluster_name)s

      This will reboot all of the instances and configure the cluster starti
      ...

  ### cluster_started_msg Value:
      '''

      The cluster has been started and configured.
      Login to the master node as root by running:

          $ starcluster sshmaster %(tag)s

      When you are finished using the cluster, run:
      ...

  ### spotmsg Value:
      '''SPOT INSTANCES ARE NOT GUARANTEED TO COME UP

      Spot instances can take a long time to come up and may not come up at
      all depending on the current AWS load and your max spot bid price.

      StarCluster will wait indefinitely until all instances come up. If thi
      s takes too long, you can cancel the start command using CTRL-C and ma
      nually wait for the spot instances to come up by periodically checking
      ...

  ### version_mismatch Value:
      '''The cluster \'%(cluster)s\' was created with a newer version of Sta
      rCluster (%(new_version)s). You\'re currently using version %(old_vers
      ion)s.

      This may or may not be a problem depending on what\'s changed between
      these versions, however, it\'s highly recommended that you use version
       %(old_version)s when using the \'%(cluster)s\' cluster.'''